/* =============================================================================
This file produces figures and tables for the Online Appendix of:

"Nepotism vs. Intergenerational Transmission of Human Capital in Academia (1088–1800)"
by David de la Croix and Marc Goñi

Detailed contents: 

	APPENDIX A: Data appendix (Table A1, A2; Figure A1)
	APPENDIX C: Identification (Figures C1, C2)
	APPENDIX E: Additional figures and tables (Table E2; Figure E8)
	APPENDIX F. Moments used in estimation with complete and complete & broad coverage (Figure F1)
	APPENDIX G. Stationarity and time trends in publications (Figures G1, G2)
	APPENDIX H. Robustness to distributional assumptions (statement)
	APPENDIX I. Linearity of beta (Figure I1; Table I1)
	APPENDIX K. Alternative measures of publications (Table K2)
	APPENDIX L. Longevity (Tables L1, L2)
	APPENDIX M: Fertility diferentials (Clogg et al. tests for table M2, col 3)

For the rest of the estimates and statistics in the online appendix, see the R files in this replication package.

Last ran: March 2024 using STATA 18

Additional notes for replicator: Run in order; directories valid if do file is open from original location within the replication package and the folder structure of the replication files is kept.
-------------------------------------------------------------------------------- */

graph drop _all
set more off


* ==============================================================================
* APPENDIX A: Data appendix
* ------------------------------------------------------------------------------

* Table A.1: Breadth of coverage
* ------------------------------------------------------------------------------
import excel "..\database\Institutions with families.xlsx", sheet("Sheet1") firstrow clear
mat define tabA1 = (.,.\.,.\.,.\.,.)
count if Cov==3
mat tabA1[1,1] = `r(N)'
count if Cov==2
mat tabA1[2,1] = `r(N)'
count if Cov==1
mat tabA1[3,1] = `r(N)'
count
mat tabA1[4,1] = `r(N)'
*
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
count if CovBroad==0 & CovComprehensive==1
mat tabA1[1,2] = `r(N)'
count if CovBroad==1 & CovComprehensive==0
mat tabA1[2,2] = `r(N)'
count if CovBroad==0 & CovComprehensive==0
mat tabA1[3,2] = `r(N)'
count 
mat tabA1[4,2] = `r(N)'
*
mat colnames tabA1 = "N insti" "N sons"
mat rownames tabA1 = "Complete" "Broad" "Partial" "All"
mat list tabA1
esttab matrix(tabA1, fmt(0 0)) using "figtabs\online appendix\tabA1", mlabel("Table A1") tex replace


* Figure A.1: Percent of father-son pairs recovered from sources with complete and broad coverage
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear

* Define variables
// Coverage
gen cov3 = 100*(CovComprehensive==1 | CovBroad==1)
// Religion
gen relig = "Catholic" if Catholic==1
replace relig = "Protestant" if Protestant==1
replace relig = "" if Fdate<1527
gen cov3excl = cov3 if Field1!="1" & Field2!="1" & Field3!="1"
// Country
gen country = ""
replace country = "Austria" if Country=="AUT"
replace country = "Belgium" if Country=="BEL"
replace country = "Switzerland" if Country=="CHE"
replace country = "Czechia" if Country=="CZE"
replace country = "Germany" if Country=="DEU"
replace country = "Denmark" if Country=="DNK"
replace country = "Spain" if Country=="ESP"
replace country = "Finland" if Country=="FIN"
replace country = "France" if Country=="FRA"
replace country = "UK" if Country=="GBR"
replace country = "Ireland" if Country=="IRL"
replace country = "Italy" if Country=="ITA"
replace country = "Netherlands" if Country=="NLD"
replace country = "Poland" if Country=="POL"
replace country = "Portugal" if Country=="PRT"
replace country = "Russia" if Country=="RUS"
replace country = "Sweden" if Country=="SWE"
// Century
gen century = "before 1200" if Fdate<=1200
replace century = "1201-1300" if Fdate>=1201 & Fdate<1300
replace century = "1301-1400" if Fdate>=1301 & Fdate<1400
replace century = "1401-1500" if Fdate>=1401 & Fdate<1500
replace century = "1501-1600" if Fdate>=1501 & Fdate<1600
replace century = "1601-1700" if Fdate>=1601 & Fdate<1700
replace century = "1701-1800" if Fdate>=1701 & Fdate<1800
replace century = "1801-1980" if Fdate>=1801

* Graphs
// Coverage by country
graph hbar cov3, over(country, sort(1) label(labsize(medlarge))) bar(1, color(gray)) ///
	ylabel(0(10)100, labs(medlarge)) ytitle(% Complete and broad sources, size(medlarge)) ///
	title(Panel A. By country, color(black) size(vlarge)) ///
	bargap(60) graphregion(fc(white) lc(white)) name(g1, replace)
// Coverage by century
graph hbar cov3, over(century, sort(1) label(labs(medlarge)) desc) bar(1, color(gray)) ///
	ylabel(0(10)100, labs(medlarge)) ytitle(% Complete and broad sources, size(medlarge)) ///
	title(Panel B. By century, color(black) size(vlarge)) ///
	bargap(60) graphregion(fc(white) lc(white)) name(g2, replace)
// Coverage by field (fathers and sons)
preserve
gen nfield1 = .
gen nfield2 = .
foreach i in 1 2 4 5{
	replace nfield1 = `i' if Field1 =="`i'"
	replace nfield2 = `i' if SField1=="`i'"
}
reshape long nfield, i(ID) j(fam)
keep if nfield!=.
gen cov3_1 = cov3 if fam==1
gen cov3_2 = cov3 if fam==2
label define fieldlabel 1 "Theologian" 2 "Lawyer" 4 "Physician" 5 "Scientist"
label values nfield fieldlabel  
graph hbar cov3_1 cov3_2, over(nfield, label(labs(medlarge))) bar(1, color(gray)) bar(2, color(gs14) lcolor(gray)) ///
	ylabel(0(10)100, labs(medlarge)) ytitle(% Complete and broad sources, size(medlarge)) ///
	title(Panel C. By field of study, color(black) size(vlarge)) ///
	bargap(60) graphregion(fc(white) lc(white)) name(g3, replace) ///
	legend(on order(1 "Fathers' main field" 2 "Sons' main field") size(medlarge) pos(6) ring(1) rows(1))
restore
// Coverage by religion
graph hbar cov3 cov3excl if University==1, over(relig, sort(1) label(labs(medlarge))) ///
	bar(1, color(gray)) bar(2, color(gs14) lcolor(gray)) ///
	ylabel(0(10)100, labs(medlarge)) ytitle(% Complete and broad sources, size(medlarge)) ///
	title(Panel D. By religion (universities after 1527), color(black) size(vlarge)) ///
	bargap(60) graphregion(fc(white) lc(white)) name(g4, replace) ///
	legend(on order(1 "All" 2 "Excluding theology") size(medlarge) pos(6) ring(1) rows(1))
// Export graphs
local panels="A B C D"
forvalues i=1/4{
local p `: word `i' of `panels''
graph export "figtabs\online appendix\figA1-panel`p'.pdf", as(pdf) name("g`i'") replace
}
graph drop _all


* Table A.2: Institutions with the largest number of father-son pairs
* ------------------------------------------------------------------------------
import excel "..\database\Institutions with families.xlsx", sheet("Sheet1") firstrow clear
gsort -Nb
l IKey Nb in 1/10


* ==============================================================================
* APPENDIX C: Identification
* ------------------------------------------------------------------------------

graph drop _all
set more off

* Figure C.1: The magnitude of nepotism (γ) and other model's parameters
* ------------------------------------------------------------------------------
* set seed for replicability
set seed 25374609		// from random.org (2022-05-26, 08:52:30 UTC)
set more off

clear
set obs 50000
local tau = 0.5
local nu  = 0.8
local nep = `tau'-`nu'
gen h1 = rnormal(2,1)
gen h2 = rnormal(1,1)

* nepotism selection
replace h1=. if h1<`tau'-`nu'
replace h2=. if h2<`tau'-`nu'

* % nepotism
gen nep1 = (h1>=`tau' & h1<=`nu')
gen nep2 = (h2>=`tau' & h2<=`nu')
summ nep1
local pnep1 = round(100*`r(mean)', 0.01)
summ nep2
local pnep2 = round(100*`r(mean)', 0.1)

* graph benchmarck
twoway (hist h2 if h2 < `tau'  & h2!=., start(`nep') lc(orange*0.3) fc(orange*0.3) width(0.1) freq) ///
	   (hist h2 if h2 >= `tau' & h2!=., start(`tau') lc(blue*0.5)   fc(blue*0.5)   width(0.1) freq) ///
	   (pcarrowi 4000 `nep' 4000 `tau' (4) "  {&nu}", lc(red) mc(red) mlabcolor(red) recast(pcbarrow)) ///
	, ylabel(0(4000)4000) xlabel(-1 " " 0(2)8) legend(on order(1 "nepotism ({&gamma}) = `pnep2' %") ring(1) position(6) region(lc(black))) ///
	title("{&nu}=0.8, {&tau}=0.5, {&mu}{subscript:h}=1, and {&sigma}{subscript:h}{superscript:2}=1", color(black) size(medsmall)) ///
	xline(`nep', lc(red) lp(dash) lw(thin)) xline(`tau', lc(red) lp(dash) lw(thin)) xtitle("Human capital of selected scholars' sons") ///
	graphregion(fc(white) lc(white)) name(a, replace) 
* graph high mean
twoway (hist h1 if h1 < `tau'  & h1!=., start(`nep') lc(orange*0.3) fc(orange*0.3) width(0.1) freq) ///
	   (hist h1 if h1 >= `tau' & h1!=., start(`tau') lc(blue*0.5)   fc(blue*0.5)   width(0.1) freq) ///
	   (pcarrowi 4000 `nep' 4000 `tau' (4) "  {&nu}", lc(red) mc(red) mlabcolor(red) recast(pcbarrow)) ///
	, ylabel(0(4000)4000) xlabel(-1 " " 0(2)8) legend(on order(1 "nepotism ({&gamma}) = `pnep1' %") ring(1) position(6) region(lc(black))) ///
	title("{&nu}=0.8, {&tau}=0.5, {&mu}{subscript:h}=2, and {&sigma}{subscript:h}{superscript:2}=1", color(black) size(medsmall)) ///
	xline(`nep', lc(red) lp(dash) lw(thin)) xline(`tau', lc(red) lp(dash) lw(thin)) xtitle("Human capital of selected scholars' sons") ///
	graphregion(fc(white) lc(white)) name(b, replace) 
********************************************************************************
clear
set obs 100000
local tau = 0.5
local nu  = 0.8
local nep = `tau'-`nu'
gen h1 = rnormal(1,1.5)
gen h2 = rnormal(1,1)

* nepotism selection
replace h1=. if h1<`tau'-`nu'
replace h2=. if h2<`tau'-`nu'

* % nepotism 
gen nep1 = (h1>=`tau' & h1<=`nu')
gen nep2 = (h2>=`tau' & h2<=`nu')
summ nep1
local pnep1 = round(100*`r(mean)', 0.1)
summ nep2
local pnep2 = round(100*`r(mean)', 0.1)

* graph high variance
twoway (hist h1 if h1 < `tau'  & h1!=., start(`nep') lc(orange*0.3) fc(orange*0.3) width(0.1) freq) ///
	   (hist h1 if h1 >= `tau' & h1!=., start(`tau') lc(blue*0.5)   fc(blue*0.5)   width(0.1) freq) ///
	   (pcarrowi 4000 `nep' 4000 `tau' (4) "  {&nu}", lc(red) mc(red) mlabcolor(red) recast(pcbarrow)) ///
	, ylabel(0(4000)4000) xlabel(-1 " " 0(2)8) legend(on order(1 "nepotism ({&gamma}) = `pnep1' %") ring(1) position(6) region(lc(black))) ///
	title("{&nu}=0.8, {&tau}=0.5, {&mu}{subscript:h}=1, and {&sigma}{subscript:h}{superscript:2}=1.5", color(black) size(medsmall)) ///
	xline(`nep', lc(red) lp(dash) lw(thin)) xline(`tau', lc(red) lp(dash) lw(thin)) xtitle("Human capital of selected scholars' sons") ///
	graphregion(fc(white) lc(white)) name(c, replace) 

graph combine a b a c, graphregion(fc(white) lc(white))
graph export "figtabs\online appendix\figC1.pdf", replace		


* Figure C.2: Identification example based on model simulations
* ------------------------------------------------------------------------------
* set seed for replicability
set seed 80158666		// from random.org (2022-06-21, 15:36:01 UTC)
set more off

clear all
set obs 10000

* Parameters
* ----------
local beta=0.6
local sigh=5
local muh = 2
local mue = 1
local pthres = 0
local tau=0
local nep1 = -1 	// Nepotism (benchmark)
local nep2 = -2.5		// High nepotism
local sige_lo=0.25	// Measurement error (benchmark)
local sige_hi=3		// High measurement error

* Human capital
* -------------
gen h0 = rnormal(`muh',sqrt(`sigh'))
gen u = rnormal((1-`beta')*`muh',sqrt(`sigh'*(1-`beta'^2)))
gen h1 = `beta'*h0+u
*gen h1 = `beta'*h0 + (1-`beta')*`muh' + rnormal(0,sqrt(`sigh'*(1-`beta'^2)))
	* % nepotism (benchmark)
	preserve
	local nu = 1
	replace h0=. if h0<`tau'
	replace h1=. if h1<`tau'-`nu'
	gen nep2 = (h1>=`tau' & h1<=`nu')
	summ nep2
	local pnep2 = round(100*`r(mean)', 0.1)
	di `pnep2'
	restore
	* % nepotism (high)
	preserve
	local nu = 2.5
	replace h0=. if h0<`tau'
	replace h1=. if h1<`tau'-`nu'
	gen nep2 = (h1>=`tau' & h1<=`nu')
	summ nep2
	local pnep2 = round(100*`r(mean)', 0.1)
	di `pnep2'
	restore
	
* Publications
* -------------
* benchmark
foreach x in 0 1{
gen ep`x'_low = rnormal(`mue',sqrt(`sige_lo'))
gen p`x'_low = h`x'+ep`x'_low
replace p`x'_low = 0 if p`x'_low<`pthres'
}
* high m.e.
foreach x in 0 1{
gen ep`x'_hi = rnormal(`mue',sqrt(`sige_hi'))
gen p`x'_hi = h`x'+ep`x'_hi
replace p`x'_hi = 0 if p`x'_hi<`pthres'
}
*

* Baseline graphs
* ---------------
* Human capital
twoway 	(kdensity h0 if h0>`tau' & h1>`nep1', lcolor(blue) lwidth(thick)) ///
		(kdensity h1 if h0>`tau' & h1>`nep1', lcolor(red) lwidth(thin)), ///
		xline(`tau',lcolor(blue) lpattern(dash) lwidth(thick)) ///
		text(0.2 `tau'  " {&tau}", place(e) size(huge) color(blue))	///
		xline(`nep1',lcolor(red) lpattern(dash) lwidth(thin)) ///
		text(0.2 `nep1'  "{&tau}-{&nu} ", place(w) size(huge) color(red))	///
		xlabel(-6 -5 -1 0 10, labsize(large)) ylabel(0 0.1 0.2, labsize(large)) graphregion(color(white)) xtitle("") ///
		legend(on order(1 "fathers" 2 "sons") rows(2) ring(0) position(1) bmargin(large) size(huge)) ///
		name(hc2)
graph export "figtabs\online appendix\figC2_panelA1.pdf", replace		
* Publications
twoway 	(kdensity p0_low if h0>`tau' & h1>`nep1', lcolor(blue) lwidth(thick)) ///
		(kdensity p1_low if h0>`tau' & h1>`nep1', lcolor(red) lwidth(thin)), ///		
		xline(`pthres', lcolor(gray) lpattern(dash) lwidth(thin)) ///
		text(0.25 `pthres'  " {&pi}", place(e) size(huge) color(gray))	///
		xlabel(-1 0 5 10 15, labsize(large)) ylabel(0 0.12 0.25, labsize(large)) graphregion(color(white)) xtitle("") ///
		legend(on order(1 "fathers" 2 "sons") rows(2) ring(0) position(1) bmargin(large) size(huge)) ///
		name(p2) 
graph export "figtabs\online appendix\figC2_panelA2.pdf", replace		
* Correlation
pwcorr p1_low p0_low if h0>`tau' & h1>`nep1', star(0.01)
local corr = round(r(rho), 0.01)
twoway  (scatter p1_low p0_low if h0>`tau' & h1>`nep1', ms(p) msiz(tiny) mcolor(gray)) ///
		(lfit p1_low p0_low if h0>`tau' & h1>`nep1', lcolor(red)), ///
		text(12 12  "corr = `corr'", place(w) size(huge) color(black))	///
		graphregion(color(white)) legend(off) xtitle("father", size(huge)) ytitle("son", size(huge)) ///
		xlabel(0 6 12, labsize(large)) ylabel(0 6 12, labsize(large)) ///
		name(cor2)
graph export "figtabs\online appendix\figC2_panelA3.pdf", replace		
* QQ plot
qqplot p1_low p0_low if h0>`tau' & h1>`nep1', xlabel(0(5)15, labsize(large)) ylabel(0(5)15, labsize(large)) msymbol(smcircle_hollow) mlw(vvthin) mlc(black) graphregion(color(white)) title("") xtitl("father", size(huge)) ytitle("son", size(huge)) ///
		name(qq2)
graph export "figtabs\online appendix\figC2_panelA4.pdf", replace		

	
* High nepotism
* -------------
* Human capital
twoway 	(kdensity h0 if h0>`tau' & h1>`nep2', lcolor(blue) lwidth(thick)) ///
		(kdensity h1 if h0>`tau' & h1>`nep2', lcolor(red) lwidth(thin)), ///
		xline(`tau',lcolor(blue) lpattern(dash) lwidth(thick)) ///
		text(0.2 `tau'  " {&tau}", place(e) size(huge) color(blue))	///
		xline(`nep2',lcolor(red) lpattern(dash) lwidth(thin)) ///
		text(0.2 `nep2'  " {&tau}-{&nu}", place(e) size(huge) color(red))	///
		legend(on order(1 "fathers" 2 "sons") rows(2) ring(0) position(1) bmargin(large) size(huge)) ///
		xlabel(-6 -5 -1 0 10, labsize(large)) ylabel(0 0.1 0.2, labsize(large)) graphregion(color(white)) xtitle("") ///
		name(hc3)
graph export "figtabs\online appendix\figC2_panelB1.pdf", replace		
* Publications
twoway 	(kdensity p0_low if h0>`tau' & h1>`nep2', lcolor(blue) lwidth(thick)) ///
		(kdensity p1_low if h0>`tau' & h1>`nep2', lcolor(red) lwidth(thin)), ///		
		xline(`pthres', lcolor(gray) lpattern(dash) lwidth(thin)) ///
		text(0.25 `pthres'  " {&pi}", place(e) size(huge) color(gray))	///
		xlabel(-1 0 5 10 15, labsize(large)) ylabel(0 0.12 0.25, labsize(large)) graphregion(color(white)) xtitle("") ///
		legend(on order(1 "fathers" 2 "sons") rows(2) ring(0) position(1) bmargin(large) size(huge)) ///
		name(p3) 
graph export "figtabs\online appendix\figC2_panelB2.pdf", replace		
* Correlation
pwcorr p1_low p0_low if h0>`tau' & h1>`nep2', star(0.01)
local corr3 = round(r(rho), 0.01)
twoway  (scatter p1_low p0_low if h0>`tau' & h1>`nep2', ms(p) msiz(tiny) mcolor(gray)) ///
		(lfit p1_low p0_low if h0>`tau' & h1>`nep2', lcolor(red)), ///
		text(12 12  "corr = `corr3'", place(w) size(huge) color(black))	///
		graphregion(color(white)) legend(off) xtitle("father", size(huge)) ytitle("son", size(huge)) ///
		xlabel(0 6 12, labsize(large)) ylabel(0 6 12, labsize(large)) ///
		name(cor3)
graph export "figtabs\online appendix\figC2_panelB3.pdf", replace		
* QQ plot
qqplot p1_low p0_low if h0>`tau' & h1>`nep2', xlabel(0(5)15, labsize(large)) ylabel(0(5)15, labsize(large)) msymbol(smcircle_hollow) mlw(vvthin) mlc(black) graphregion(color(white)) title("") xtitl("father", size(huge)) ytitle("son", size(huge)) ///
		name(qq3) 
graph export "figtabs\online appendix\figC2_panelB4.pdf", replace		


* High m.e.
* -------------
* Human capital
twoway 	(kdensity h0 if h0>`tau' & h1>`nep1', lcolor(blue) lwidth(thick)) ///
		(kdensity h1 if h0>`tau' & h1>`nep1', lcolor(red) lwidth(thin)), ///
		xline(`tau',lcolor(blue) lpattern(dash) lwidth(thick)) ///
		text(0.2 `tau'  " {&tau}", place(e) size(huge) color(blue))	///
		xline(`nep1', lcolor(red) lpattern(dash) lwidth(thin)) ///
		text(0.2 `nep1'  "{&tau}-{&nu} ", place(w) size(huge) color(red))	///
		legend(on order(1 "fathers" 2 "sons") rows(2) ring(0) position(1) bmargin(large) size(huge)) ///
		xlabel(-6 -5 -1 0 10, labsize(large)) ylabel(0 0.1 0.2, labsize(large)) graphregion(color(white)) xtitle("") ///
		name(hc4)
graph export "figtabs\online appendix\figC2_panelC1.pdf", replace		
* Publications
twoway 	(kdensity p0_hi if h0>`tau' & h1>`nep1', lcolor(blue) lwidth(thick)) ///
		(kdensity p1_hi if h0>`tau' & h1>`nep1', lcolor(red) lwidth(thin)), ///		
		xline(`pthres', lcolor(gray) lpattern(dash) lwidth(thin)) ///
		text(0.25 `pthres'  " {&pi}", place(e) size(huge) color(gray))	///
		xlabel(-1 0 5 10 15, labsize(large)) ylabel(0 0.12 0.25, labsize(large)) graphregion(color(white)) xtitle("") ///
		legend(on order(1 "fathers" 2 "sons") rows(2) ring(0) position(1) bmargin(large) size(huge)) ///
		name(p4) 
graph export "figtabs\online appendix\figC2_panelC2.pdf", replace		
* Correlation
pwcorr p1_hi p0_hi if h0>`tau' & h1>`nep1'
local corr4 = round(r(rho), 0.01)
twoway  (scatter p1_low p0_low if h0>`tau' & h1>`nep1', ms(p) msiz(tiny) mcolor(gray)) ///
		(lfit p1_low p0_low if h0>`tau' & h1>`nep1', lcolor(red)), ///
		text(12 12  "corr = `corr4'", place(w) size(huge) color(black))	///
		graphregion(color(white)) legend(off) xtitle("father", size(huge)) ytitle("son", size(huge)) ///
		xlabel(0 6 12, labsize(large)) ylabel(0 6 12, labsize(large)) ///
		name(cor4)
graph export "figtabs\online appendix\figC2_panelC3.pdf", replace		
* QQ plot
qqplot p1_hi p0_hi if h0>`tau' & h1>`nep1', xlabel(0(5)15, labsize(large)) ylabel(0(5)15, labsize(large)) msymbol(smcircle_hollow) mlw(vvthin) mlc(black) graphregion(color(white)) title("") xtitl("father", size(huge)) ytitle("son", size(huge))  ///
		name(qq4) 
graph export "figtabs\online appendix\figC2_panelC4.pdf", replace
graph drop _all	


* ==============================================================================
* APPENDIX E: Additional figures and tables
* ------------------------------------------------------------------------------

* Figure E.8: Field-institution growth rates in publications over time
* --------------------------------------------------------------------
import excel "..\high-low-growth\fields-over-time.xlsx", sheet("Sheet1") firstrow clear
keep if year>=1200
local i = 1
foreach x in publitheocathgrowth publilawcathgrowth publihumcathgrowth publimedcathgrowth publiscicathgrowth publiappcathgrowth publitheoprotgrowth publilawprotgrowth publihumprotgrowth publimedprotgrowth publisciprotgrowth publiappprotgrowth{
	rename `x' g`i'
	local i = `i'+1
}
reshape long g, i(year) j(field_religion)
label define lblg 1 "Theology" 2 "Law" 3 "Humanities" 4 "Medicine" 5 "Science" 6 "Applied science" 7 "Theology" 8 "Law" 9 "Humanities" 10 "Medicine" 11 "Science" 12 "Applied science"
label values field_religion lblg
keep if year>1525 
preserve
keep if field_religion<7
twoway (line g year if g>0 & year<1650, sort) (line g year if g<0, sort) (line g year if g>0 & year>=1650, sort lc(stc1)) ///
	, by(field_religion, legend(off)) ytitle("Growth rate in publications") xtitle("Year") yline(0) name(gcath, replace)
graph export "figtabs\online appendix\figE8_panelA.pdf", replace		
restore
preserve
keep if field_religion>=7
twoway (line g year if g>0, m(p)) (line g year if g<0, m(p)) ///
	, by(field_religion, legend(off)) ytitle("Growth rate in publications") xtitle("Year") yline(0) name(gprot, replace)
graph export "figtabs\online appendix\figE8_panelB.pdf", replace	
graph drop _all	
restore


* Table E.2: Dep. variable = 1 if scholar hasWikipedia page
* ---------------------------------------------------------
* Fathers' indicator
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
collapse Flibh, by(Father)
rename Father PKey
gen ifather = 1
save "dta\fathers.dta", replace

* Sons and all data
import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
merge m:1 PKey using "dta\fathers.dta", keep(mas mat)

* Library holdings
gen libhold = 0 if publications==0
replace libhold = sinh(publications) if publications>0
gen publi = asinh(libhold)

* Institutions
preserve
import excel "..\base\Profs.xlsx", sheet("Profs") firstrow clear
sort PKey Beginning
by PKey: gen dup = _n
drop if dup>1
keep PKey IKey Field
tempfile ikeys
save `ikeys', replace
restore
merge m:1 PKey using `ikeys', keep(mas mat) nogen

* sample
// drop top 1%
qui summ publications, d
drop if publications>=`r(p99)'
// worldcat broad and comprehensive
keep if worldcat==1 & (covBroad==1 | covComprehensive==1)
count if (group=="All" & ifather!=1) | (group=="Sons")

gen ison = (group=="Sons")
label var ison "Scholar's son (0/1)"
label var publi "Publications (arcsinh)"
reg wiki ison publi if (group=="All" & ifather!=1) | (group=="Sons"), cluster(date)
	outreg2 using "figtabs\online appendix\tabE2", keep(ison publi) nocons ///
	addtext(Cohort FE, ., Institution FE, ., Field FE, ., Number of library holdings FE, .) ///
	nonotes addnote(SE clustered by cohort, *p<.05; **p<.01; ***p<.001) ///
	label dec(3) tex(fragment) long replace
xi: reghdfe wiki ison publi if (group=="All" & ifather!=1) | (group=="Sons"), absorb(date) cl(date)
	outreg2 using "figtabs\online appendix\tabE2", keep(ison publi) nocons ///
	addtext(Cohort FE, Y, Institution FE, ., Field FE, ., Number of library holdings FE, .) ///
	nonotes addnote(SE clustered by cohort, *p<.05; **p<.01; ***p<.001) ///
	label dec(3) tex(fragment) long
xi: reghdfe wiki ison publi if (group=="All" & ifather!=1) | (group=="Sons"), absorb(date IKey) cl(date)
	outreg2 using "figtabs\online appendix\tabE2", keep(ison publi) nocons ///
	addtext(Cohort FE, Y, Institution FE, Y, Field FE, ., Number of library holdings FE, .) ///
	nonotes addnote(SE clustered by cohort, *p<.05; **p<.01; ***p<.001) ///
	label dec(3) tex(fragment) long
xi: reghdfe wiki ison publi if (group=="All" & ifather!=1) | (group=="Sons"), absorb(date IKey Field) cl(date)
	outreg2 using "figtabs\online appendix\tabE2", keep(ison publi) nocons ///
	addtext(Cohort FE, Y, Institution FE, Y, Field FE, Y, Number of library holdings FE, .) ///
	nonotes addnote(SE clustered by cohort, *p<.05; **p<.01; ***p<.001) ///
	label dec(3) tex(fragment) long
xi: reghdfe wiki ison if (group=="All" & ifather!=1) | (group=="Sons"), absorb(date IKey Field libhold) cl(date)
	outreg2 using "figtabs\online appendix\tabE2", keep(ison) nocons ///
	addtext(Cohort FE, Y, Institution FE, Y, Field FE, Y, Number of library holdings FE, Y) ///
	nonotes addnote(SE clustered by cohort, *p<.05; **p<.01; ***p<.001) ///
	label dec(3) tex(fragment) long



* ==============================================================================
* APPENDIX F: Moments used in estimation with complete and complete & broad coverage
* ------------------------------------------------------------------------------

* Figure F.1: Quantile-quantile, by data coverage
* -----------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
count
local nobs = `r(N)'
qqplot 	Spubli Fpubli, ///
		msymbol(circle_hollow) mlw(vthin) ///
		xlabel(0(2)14) ylabel(0(2)14) ///
		xtitle("Fathers' arcsinh-library holdings") ytitle("Sons' arcsinh-library holdings") ///
		title("All", color(black)) text(11.5 3 "N = `nobs'")	///
		name(A, replace)
keep if CovComprehensive==1 | CovBroad==1
count
local nobs = `r(N)'
qqplot 	Spubli Fpubli, ///
		msymbol(circle_hollow) mlw(vthin) ///
		xlabel(0(2)14) ylabel(0(2)14) ///
		xtitle("Fathers' arcsinh-library holdings") ytitle("Sons' arcsinh-library holdings") ///
		title("Complete & Broad", color(black)) text(11.5 3 "N = `nobs'")	///
		name(B, replace)
keep if CovComprehensive==1
count
local nobs = `r(N)'
qqplot 	Spubli Fpubli, ///
		msymbol(circle_hollow) mlw(vthin) ///
		xlabel(0(2)14) ylabel(0(2)14) ///
		xtitle("Fathers' arcsinh-library holdings") ytitle("Sons' arcsinh-library holdings") ///
		title("Complete", color(black)) text(11.5 3 "N = `nobs'")	///
		name(C, replace)
graph combine A B C, rows(1) graphregion(color(white))
graph export "figtabs\online appendix\figF1.pdf", as(pdf) name("Graph") replace



* ==============================================================================
* APPENDIX G: Stationarity and time trends in publications
* ------------------------------------------------------------------------------

* Figure G.1: Trend in standard error of the mean, arcsinh-library holdings
* -------------------------------------------------------------------------
import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
gen libh = sinh(publications)
gen period = .
forvalues t = 975(25)1775{
replace period = `t' if date>=`t' & date<`t'+25
}
replace period = 1775 if date>1775
gen publications_int = .
replace publications_int = publications if libh>0
gen publications_ext = (libh>0)
keep if date >= 1088
collapse (sem) _sd = publications (sem) _int_sd = publications_int (sem) _ext_sd = publications_ext, by(period)
twoway (connect _sd period) ///
	, title("") legend(off) ytitle("SEM, arcsinh-library holdings") xtitle(" ") ///
	xlabel(1000 "1000-1025" 1200 "1200-1225" 1400 "1400-1425" 1600 "1600-1625" 1775 "1775-1800   .")
graph export "figtabs\online appendix\figG1.pdf", replace


* NUMBER OF OBS BEFORE 1350
* -------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
tabmiss Sdate if Sdate<1350

* Figure G.2: Trend in log-publications, intensive and extensive margin: 
* Intensive margin
* ----------------------------------------------------------------------
import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
keep if date >= 1088
keep if worldcat==1
gen libh = sinh(publications)
label var date "Year"
label var publications "Arcsinh-library holdings | listed in WorldCat"
lpoly publications date if libh>0, noci ///
	msymbol(oh) mlwidt(vthin) lineopt(lwidth(thick)) ///
	xlabel(1000(200)1800, labs(large)) ylabel(0(5)15, labs(large)) ///
	note(, size(medlarge)) title("Intensive margin", size(huge)) xtitle("Year", size(large)) ytitle("Arcsinh-publi | listed in WorldCat", size(large)) graphregion(color(white)) 
graph export "figtabs\online appendix\figG2_toppanel.pdf", replace
	
* Figure G.2: Trend in log-publications, intensive and extensive margin: 
* Extensive margin
* ----------------------------------------------------------------------
import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
keep if date >= 1088
label var date "year"
gen lin = (worldcat==1)
label var lin "Share listed in WorldCat"
lpoly lin date, noci ///
	xline(1450, lpattern(dash) lcolor(black) lwidth(thick)) ///
	msymbol(oh) mlwidt(vthin) lineopt(lwidth(thick)) ///
	xlabel(1000(200)1800, labs(large)) ylabel(0(0.2)1, labs(large)) ///
	note(, size(medlarge)) title("Extensive margin", size(huge)) xtitle("Year", size(large)) ytitle("Share listed in WorldCat", size(large)) graphregion(color(white)) 
graph export "figtabs\online appendix\figG2_bottompanel.pdf", replace



* ==============================================================================
* APPENDIX H: Robustness to distributional assumptions
* ------------------------------------------------------------------------------

* "our two main estimates---the intergenerational human capital elasticity, $\beta$, and the magnitude of nepotism, $\gamma$---are not significantly different when we target the moments in $V_(p)$ or in $V_S(p)$."
clear
set obs 1
gen test = "bench vs spearman model" if _n==1
gen b_z = .
gen b_pval = .
gen n_z = .
gen n_pval = .
* bench
local b1 = 0.63
local sb1 = 0.04
local n1 = 18.7
local sn1 = 1.7
* spearman
local b2 = 0.70
local sb2 = 0.04
local n2 = 19.1
local sn2 = 1.7
foreach x in b n{
replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2)) if _n==1
replace `x'_pval = 2*normal(-`x'_z)
replace `x'_z = round(`x'_z, 0.01)
replace `x'_pval = round(`x'_pval, 0.01)
}
l


* ==============================================================================
* APPENDIX I: Linearity of beta
* ------------------------------------------------------------------------------

* Figure I.1: Parent-child publications' elasticity (intensive margin), OLS and kernel-weighted local polynomial regression
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
lpoly Spubli Fpubli if Spubli>0 & Fpubli>0, ///
	msymbol(oh) mlwidt(thin) lineopt(lwidth(thick)) ///
	title("") graphregion(color(white)) degree(1) ci ///
	addplot(lfit Spubli Fpubli if Spubli>0 & Fpubli>0, lpattern(dash) lcolor(black)) ///
	xtitle("Father's arcsinh library holdings") ///
	ytitle("Son's arcsinh library holdings") ///
	legend(on order(1 "95% CI" 3 "Non-parametric" 4 "OLS") rows(1) ring(0) position(1) bmargin(large))
graph export "figtabs\online appendix\figI1.pdf", replace

* Table I.1: Parent-child publications' elasticity (intensive margin), OLS and Non-parametric estimates
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
keep if Spubli>0 & Fpubli>0 	// intensive margin
* All families
reg Spubli Fpubli
outreg2 using "figtabs\online appendix\tabI1_row1", keep(Fpubli) tex ctitle("OLS") label dec(2) nocons nor2 replace
npregress kernel Spubli Fpubli, reps(1000) seed(1)
outreg2 using "figtabs\online appendix\tabI1_row1", keep(Fpubli) tex ctitle("np") label dec(2) nocons nor2
* Pre-SR
reg Spubli Fpubli if Fdate<=1543 
outreg2 using "figtabs\online appendix\tabI1_row2", keep(Fpubli) tex ctitle("OLS") label dec(2) nocons nor2 replace
npregress kernel Spubli Fpubli if Fdate<=1543, reps(1000) seed(1)
outreg2 using "figtabs\online appendix\tabI1_row2", keep(Fpubli) tex ctitle("np") label dec(2) nocons nor2
* SR (1)
reg Spubli Fpubli if Fdate>1543 & Fdate<=1632
outreg2 using "figtabs\online appendix\tabI1_row3", keep(Fpubli) tex ctitle("OLS") label dec(2) nocons nor2 replace
npregress kernel Spubli Fpubli if Fdate>1543 & Fdate<=1632, reps(1000) seed(1)
outreg2 using "figtabs\online appendix\tabI1_row3", keep(Fpubli) tex ctitle("np") label dec(2) nocons nor2
* SR (2)
reg Spubli Fpubli if Fdate>1632 & Fdate<=1687
outreg2 using "figtabs\online appendix\tabI1_row4", keep(Fpubli) tex ctitle("OLS") label dec(2) nocons nor2 replace
npregress kernel Spubli Fpubli if Fdate>1632 & Fdate<=1687, reps(1000) seed(1)
outreg2 using "figtabs\online appendix\tabI1_row4", keep(Fpubli) tex ctitle("np") label dec(2) nocons nor2
* Enlightenment
reg Spubli Fpubli if Fdate>1687 & Fdate<=1800
outreg2 using "figtabs\online appendix\tabI1_row5", keep(Fpubli) tex ctitle("OLS") label dec(2) nocons nor2 replace
npregress kernel Spubli Fpubli if Fdate>1687 & Fdate<=1800, reps(1000) seed(1)
outreg2 using "figtabs\online appendix\tabI1_row5", keep(Fpubli) tex ctitle("np") label dec(2) nocons nor2


* ==============================================================================
* APPENDIX K: Alternative measures of publications
* ------------------------------------------------------------------------------

* Table K.2: Comparison of distributions
* -------------------------------------
local FQ50base = 5.075
local SQ50base = 3.402
local FQ75base = 7.370
local SQ75base = 6.413
local FQ95base = 9.425
local SQ95base = 8.537
local FMEAbase = 4.456
local SMEAbase = 3.477
*
local FQ50pubby = 4.238
local SQ50pubby = 2.615
local FQ75pubby = 6.300
local SQ75pubby = 5.415
local FQ95pubby = 8.213
local SQ95pubby = 7.306
local FMEApubby = 3.752
local SMEApubby = 2.893
*
local FQ50uniq = 3.801
local SQ50uniq = 2.440
local FQ75uniq = 5.762
local SQ75uniq = 4.950
local FQ95uniq = 7.568
local SQ95uniq = 6.748
local FMEAuniq = 3.441
local SMEAuniq = 2.664
*
mat define tabK2 = (`FQ50base'/`FQ75base',`FQ50pubby'/`FQ75pubby',`FQ50uniq'/`FQ75uniq' \ `SQ50base'/`SQ75base',`SQ50pubby'/`SQ75pubby',`SQ50uniq'/`SQ75uniq' \ `FQ50base'/`FQ95base',`FQ50pubby'/`FQ95pubby',`FQ50uniq'/`FQ95uniq' \ `SQ50base'/`SQ95base',`SQ50pubby'/`SQ95pubby',`SQ50uniq'/`SQ95uniq' \ `FQ50base'/`FMEAbase',`FQ50pubby'/`FMEApubby',`FQ50uniq'/`FMEAuniq' \ `SQ50base'/`SMEAbase',`SQ50pubby'/`SMEApubby',`SQ50uniq'/`SMEAuniq')
mat colnames tabK2 = "baseline" "pubby" "unique works"
mat rownames tabK2 = "F, Q50 Q75" "S, Q50 Q75" "F, Q50 Q95" "S, Q50 Q95" "F, Q50 mean" "S, Q50 mean" 
mat list tabK2
esttab matrix(tabK2, fmt(2 2 2))
esttab matrix(tabK2, fmt(2 2 2)) using "figtabs\online appendix\tabK2.tex", mlabel("Table coverage") replace


* ==============================================================================
* APPENDIX L: Longevity
* ------------------------------------------------------------------------------

* difference in years
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
keep ID Slongevity Flongevity
rename Flongevity longevity1
rename Slongevity longevity2
reshape long longevity, i(ID) j(generation)
ttest longevity, by(generation)

* TABLE L.1. The effect of Longevity on son's distributional moments
* TABLE L.2. Distributional moments adjusted for longevity differentials
* ----------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
gen Szero = 1-Sin
gen Fzero = 1-Fin
label var Slongevity "Longevity (years)"

* difference 
summ Slongevity
local Slongevity_mean = `r(mean)'
summ Flongevity
local Flongevity_mean = `r(mean)'
local FSldiff = `Flongevity_mean'-`Slongevity_mean'
di `FSldiff'

* mean
summ Spubli
local mmean = `r(mean)'
reg Spubli Slongevity
outreg2 using "figtabs\online appendix\tabL1", keep(Slongevity) nocons ///
	ctitle("mean") addtext(Sample, sons) ///
	nonotes addnote(*p<.05; **p<.01; ***p<.001) ///
	label dec(3) tex(fragment) nor2 long replace
local adjmmean = `mmean'+`FSldiff'*_b[Slongevity]
di `mmean'
di `adjmmean'

* Zero publications:
summ Szero
local m0 = `r(mean)'
reg Szero Slongevity
outreg2 using "figtabs\online appendix\tabL1", keep(Slongevity) nocons ///
	ctitle("zeros") addtext(Sample, sons) ///
	nonotes addnote(*p<.05; **p<.01; ***p<.001) ///
	label dec(4) tex(fragment) nor2 long

local adjm0 = `m0'+`FSldiff'*_b[Slongevity]
di `m0'
di `adjm0'

* Q50, Q75, and Q95
summ Spubli, d
local mQ50 = `r(p50)'
local mQ75 = `r(p75)'
local mQ95 = `r(p95)'
sqreg Spubli Slongevity, q(.5 .75 .95)
outreg2 using "figtabs\online appendix\tabL1", ///
	keep(Slongevity) nocons bdec(3) sdec(3) ///
	addtext(Sample, sons) ///
	nonotes addnote(*p<.05; **p<.01; ***p<.001) ///
	label tex
sqreg Spubli Slongevity, q(.5 .75 .95)

local adjmQ50 = `mQ50'+`FSldiff'*r(table)[1,1]
local adjmQ75 = `mQ75'+`FSldiff'*r(table)[1,3]
local adjmQ95 = `mQ95'+`FSldiff'*r(table)[1,5]

* estout results
mat define tabAGE = (.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.)
mat tabAGE[2,1] = `m0'
mat tabAGE[2,2] = `adjm0'
mat tabAGE[2,3] = `m0'-`adjm0'
mat tabAGE[4,1] = `mQ50'
mat tabAGE[4,2] = `adjmQ50'
mat tabAGE[4,3] = `mQ50'-`adjmQ50'
mat tabAGE[6,1] = `mQ75'
mat tabAGE[6,2] = `adjmQ75'
mat tabAGE[6,3] = `mQ75'-`adjmQ75'
mat tabAGE[8,1] = `mQ95'
mat tabAGE[8,2] = `adjmQ95'
mat tabAGE[8,3] = `mQ95'-`adjmQ95'
mat tabAGE[10,1] = `mmean'
mat tabAGE[10,2] = `adjmmean'
mat tabAGE[10,3] = `adjmmean'-`mmean'
	// fathers & N (from table 2)
	mat tabAGE[1,1] = 0.288
	mat tabAGE[3,1] = 5.075
	mat tabAGE[5,1] = 7.370
	mat tabAGE[7,1] = 9.425
	mat tabAGE[9,1] = 4.456
mat colnames tabAGE = "Baseline" "Adjusted" "Difference"
mat rownames tabAGE = "Fathers with zero pubs." "Sons with zero pubs." "Fathers median" "Sons median" "Fathers 75th percentile" "Sons 75th percentile" "Fathers 95th percentile" "Sons 95th percentile" "Fathers mean" "Sons mean"
esttab matrix(tabAGE, fmt(2 2 2))
esttab matrix(tabAGE, fmt(2 2 2)) using "figtabs\online appendix\tabL2", mlabel("Table L2") tex replace


* ==============================================================================
* APPENDIX M: Fertility diferentials
* ------------------------------------------------------------------------------

* Table M.2: Robustness to fertility differentials within academia
* Clogg et al tests (see R files for estimates)
* ------------------------------------------------------------------------------
clear
set obs 1
gen test = "Difference" if _n==1
foreach x in beta gamma sige sigh muh k{ 
gen `x'_z = .
gen `x'_pval = .
}

* INFO FROM TABLE M.2
* -------------------
* Baseline estimation
local beta1 = 0.63
local gamma1 = 18.7
local muh1 = 1.87
local sigh1 = 4.22
local sige1 = 0.39
local k1 = 2.12
*
local sbeta1 = 0.04
local sgamma1 = 1.74
local smuh1 = 0.47
local ssigh1 = 0.20
local ssige1 = 0.15
local sk1 = 0.14

* Estimation with parity 1 fathers
local beta2 = 0.68
local gamma2 = 19.4
local muh2 = 1.41
local sigh2 = 4.36
local sige2 = 0.47
local k2 = 2.06
*
local sbeta2 = 0.05
local sgamma2 = 2.13
local smuh2 = 0.61
local ssigh2 = 0.25
local ssige2 = 0.18
local sk2 = 0.15

* CLOGG TESTS
* ---------------------------------
foreach x in beta gamma muh sigh sige k{ 
replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2)) if _n==1
replace `x'_pval = 2*normal(-`x'_z)
replace `x'_z = round(`x'_z, 0.001)
replace `x'_pval = round(`x'_pval, 0.001)
}
l
* ==============================================================================
