/* =============================================================================
This file produces figures, tables, and numbers reported in the text for:

"Nepotism vs. Intergenerational Transmission of Human Capital in Academia (1088–1800)"
by David de la Croix and Marc Goñi

Detailed contents: 

	Numbers reported in the text
	Figure 1: Publications of sons of scholars relative to outsiders overtime
	Table 1: Data coverage (in %)
 	Figure 3: Number of scholar families and father's publications
	Figure 6: Empirical and simulated distribution of publications
	Figure 7: Publications, by institution's religious affiliation
	Table 5: Heterogeneity (only Clogg et al tests, see R-files for estimates)
 	Table 6: Identified parameters using estimation strategy with outsiders (column [3], see R files for estimates)
	Table 7: Intergenerational elasticites amongs scholars, different methods

For the rest of the estimates and statistics in the paper, see the R files in this replication package.

Last ran: March 2024 using STATA 18

Additional notes for replicator: Run in order; directories valid if do file is open from original location within the replication package and the folder structure of the replication files is kept.
-------------------------------------------------------------------------------- */

graph drop _all
set more off


* ==============================================================================
* 0. NUMBERS IN PAPER
* Notes: these numbers are generally reproduced in the order in which they appear in the text; headings help to locate the reproduced number in the text; quotes may be inexact due to small editorial and language changes in the final manuscript.
* ------------------------------------------------------------------------------
* NUMBER OF INSTITUTIONS
	import excel "..\database\Institutions with families.xlsx", sheet("Sheet1") firstrow clear
	di _N
	tab Univ // -1 = university; 0 = academy

* EFFECT IN STANDARD DEVIATIONS
	local nu 8.989
	local muh 1.865
	local sigmah 4.219
	local tau 0
	di (`muh'-(`tau'-`nu')) / `sigmah'		// vs. average scholar
	di (`tau'-(`tau'-`nu')) / `sigmah'		// vs. marginal scholar

* NUMBERS BASED ON ALL SCHOLARS
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	collapse Flibh, by(Father)
	rename Father PKey
	gen ifather = 1
	save "dta\fathers.dta", replace
	import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
	merge m:1 PKey using "dta\fathers.dta", keep(mas mat)
	gen libhold = 0 if publications==0
	replace libhold = sinh(publications)-1 if publications>0
	gen alibhold = libhold if group=="All" & ifather!=1 	// outsiders
	gen slibhold = libhold if group=="Sons"					// sons
	qui summ publications, d
	drop if publications>=`r(p99)'
	keep if worldcat==1 & (covBroad==1 | covComprehensive==1)
	// \bigpictureOUT
	count if (group=="All" & ifather!=1) | (group=="Sons")
	// 1 in 20 (0.05) scholars worked in the same university or academy as his father
	count if (group=="All" & ifather!=1) | (group=="Sons")
	local all = `r(N)'
	count if (group=="Sons") 
	local sons = `r(N)'
	di `sons'/`all'
	// the library holdings of the average son are 83.4\% those of the average outsider
	gen sons = 1 if group=="Sons"
	collapse (mean) alibhold (mean) slibhold (count) sons, by(date)
	tsset date
	keep if date>1250
	gen asinhalibhold = asinh(alibhold)
	gen asinhslibhold = asinh(slibhold)
	tssmooth ma ma_aw1 = asinhalibhold, window(25 1 25)
	tssmooth ma ma_sw1 = asinhslibhold, window(25 1 25)
	tssmooth ma ma_aw2 = asinhalibhold, window(50 1 50)
	tssmooth ma ma_sw2 = asinhslibhold, window(50 1 50)
	gen ma_aw = ma_aw1 if date>1400
	replace ma_aw = ma_aw2 if date<=1400
	gen ma_sw = ma_sw1 if date>1400
	replace ma_sw = ma_sw2 if date<=1400
	gen ratio = ma_sw/ma_aw
	summ ratio
	di round(100*`r(mean)',0.1)

* TOTAL NUMBER OF LIBRARY HOLDINGS AND UNIQUE WORKS
	clear 
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow 
	collapse Sworks Fworks Slibh Flibh, by(Son)
	collapse (sum) Sworks (sum) Slibh
	l
	clear 
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow 
	collapse Sworks Fworks Slibh Flibh, by(Father)
	collapse (sum) Fworks (sum) Flibh
	l
	* uworks
	di 146196  + 340845
	* libhold
	di 1039684 + 3067217
	
* STATEMENT: "These universities had, on average, 410 scholars and 11.8 academic dynasties"
	import excel "..\base\Profs.xlsx", sheet("Profs") firstrow clear
	gen n = 1
	collapse (sum) n, by(IKey)
	tempfile inb
	save `inb', replace
	import excel "..\database\Institutions with families.xlsx", sheet("Sheet1") firstrow clear
	keep if Univ==-1
	merge 1:1 IKey using `inb', keep(mas mat)
	summ n
	*
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	gen nobs = 1
	collapse (sum) nobs, by(IKey Country University)
	summ nobs if University==1
	di round(`r(mean)',0.1)
	
* GEOGRAPHICAL COVERAGE
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	gen nobs = 1
	collapse (sum) nobs, by(IKey Country University)
	tab Country if University==1
	tab Country if University==0
	* HRE:
	tab Country if University==1 & (Country=="AUT" | Country=="BEL" | Country=="CZE" | Country=="DEU")
	tab Country if University==0 & (Country=="AUT" | Country=="BEL" | Country=="CZE" | Country=="DEU")
	* west europe:
	tab Country if University==1 & (Country=="FRA")
	tab Country if University==0 & (Country=="FRA")
	tab Country if University==1 & (Country=="GBR")
	tab Country if University==0 & (Country=="GBR")
	tab Country if University==1 & (Country=="NLD")
	tab Country if University==0 & (Country=="NLD")
	* south europe:
	tab Country if University==1 & (Country=="ITA")
	tab Country if University==0 & (Country=="ITA")
	tab Country if University==1 & (Country=="ESP")
	tab Country if University==0 & (Country=="ESP")

* STATEMENT: "More than half of the universities in our dataset were established before 1500"
	import excel "..\database\Institutions with families.xlsx", sheet("Sheet1") firstrow clear
	drop if Univ==0
	gen founded=substr(IKey,-4,.)
	split IKey, parse("-") limit(1) gen(uni)
	destring founded, replace
	gen estbef1500 = (founded<1500)
	tab estbef1500

* NB. FAMILIES BEFORE 1400
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	count if Fdate<1400
	
* PUBLICATIONS BY DIFFERENT FAMILIES
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	* Bicais
	l Father Flibh if Father=="Bicais-H-1590"	// father
	l Son Slibh if Father=="Bicais-H-1590"	// son
	* Bauhin
	l Son Slibh if Son=="Bauhin-J-1541"
	* Benavente
	l Father Flibh if Father=="Benavente-JA-13??"
	
* % WITHOUT WC ENTRY (from moments.txt)

* TOTAL NUMBER OF LIBRARY HOLDINGS AND UNIQUE WORKS
	clear 
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow 
	collapse Sworks Fworks Slibh Flibh, by(Son)
	collapse (sum) Sworks (sum) Slibh
	l
	clear 
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow 
	collapse Sworks Fworks Slibh Flibh, by(Father)
	collapse (sum) Fworks (sum) Flibh
	l
	* uworks
	di 146196  + 340845
	* libhold
	di 1039684 + 3067217
	
* FOOTNOTE: "The differences in levels are $sinh(4.456)=43.07$ vs. $sinh(3.477)=16.17$ in the mean and $sinh(5.075)=79.983$ vs. $sinh(3.402)=14.995$ in the median."
	di sinh(4.456)
	di sinh(3.477)
	di sinh(5.075)
	di sinh(3.402)

* TABLE 1: "These three estimates [gamma] are not statistically different from each other, strongly suggesting that our results are not driven by sampling bias in the recording of father-son links."
	clear
	set obs 3
	gen test = "Baseline vs complete" if _n==1
	replace test = "Baseline vs complete and broad" if _n==2
	replace test = "Complete vs complete and broad" if _n==3
	gen b_z = .
	gen b_pval = .
	gen n_z = .
	gen n_pval = .
	* Baseline
	local b1 = 0.63
	local sb1 = 0.04
	local n1 = 18.7
	local sn1 = 1.74
	* Complete
	local b2 = 0.59
	local sb2 = 0.05
	local n2 = 14.8
	local sn2 = 2.14
	* Complete and broad
	local b3 = 0.64
	local sb3 = 0.04
	local n3 = 18.2
	local sn3 = 1.77
	* CLOGG ET AL. TESTS
	foreach x in b n{
	replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2)) if _n==1
	replace `x'_z = abs((``x'1' - ``x'3')/sqrt((`s`x'1')^2+(`s`x'3')^2)) if _n==2
	replace `x'_z = abs((``x'2' - ``x'3')/sqrt((`s`x'2')^2+(`s`x'3')^2)) if _n==3
	replace `x'_pval = 2*normal(-`x'_z)
	replace `x'_z = round(`x'_z, 0.01)
	replace `x'_pval = round(`x'_pval, 0.01)
	}
	l

* Beta vs. elasticity comparison
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	gen logSpubli = log(1+Slibh)
	gen logFpubli = log(1+Flibh)
	reg logSpubli logFpubli
	reg logSpubli logFpubli if CovComprehensive==1
	*
	local b1 = 0.63
	local sb1 = 0.04
	local b2 = 0.46
	local sb2 = 0.02
	local z = abs((`b1' - `b2')/sqrt((`sb1')^2+(`sb2')^2))
	local pval = 2*normal(-`z')
	di `z'
	di `pval'
	*
	local b1 = 0.59
	local sb1 = 0.05
	local b2 = 0.48
	local sb2 = 0.02
	local z = abs((`b1' - `b2')/sqrt((`sb1')^2+(`sb2')^2))
	local pval = 2*normal(-`z')
	di `z'
	di `pval'

* PARAMETERS FROM STATIONARITY CONDITIONS (MU_u & sigma_u)
	local B = 0.63
	local mu_h = 1.87
	local sigma_h = 4.22
	// Mu_u
	di round((1-`B')*`mu_h',0.01)
	// Sigma_u
	di round(sqrt((1-`B'^2)*`sigma_h'^2),0.01)
	
* ESTIMATED KAPPA IN LEVELS
	* "implying that a scholar who published 2 or 3 works may have no library holdings today." Note: model in logs so kappa in logs
	local kappa = 2.12
	di exp(`kappa'-1)
	
* TABLE 2: "These percentages [gamma] are precisely estimated and significantly different from each other: a Clogg et al.'s z-test rejects the null hypothesis of no difference in nepotism between the period before 1543, the Scientific Revolution, and the Enlightenment."
	clear
	set obs 5
	gen test = "pre-1543 vs SR (I)" if _n==1
	replace test = "pre-1543 vs SR (II)" if _n==2
	replace test = "pre-1543 vs Enlightenment" if _n==3
	replace test = "SR (I) vs Enlightenment" if _n==4
	replace test = "SR (II) vs Enlightenment" if _n==5
	gen b_z = .
	gen b_pval = .
	gen n_z = .
	gen n_pval = .
	* pre-1543
	local b1 = 0.18
	local sb1 = 0.14
	local n1 = 48.82
	local sn1 = 10.42
	* SR(I)
	local b2 = 0.62
	local sb2 = 0.08
	local n2 = 20.35
	local sn2 = 3.98
	* SR(II)
	local b3 = 0.59
	local sb3 = 0.08
	local n3 = 17.96
	local sn3 = 2.74
	*Englightenment
	local b4 = 0.67
	local sb4 = 0.06
	local n4 = 8.29
	local sn4 = 3.51
	* CLOGG ET AL. TESTS
	foreach x in b n{
	replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2)) if _n==1
	replace `x'_z = abs((``x'1' - ``x'3')/sqrt((`s`x'1')^2+(`s`x'3')^2)) if _n==2
	replace `x'_z = abs((``x'1' - ``x'4')/sqrt((`s`x'1')^2+(`s`x'4')^2)) if _n==3
	replace `x'_z = abs((``x'2' - ``x'4')/sqrt((`s`x'2')^2+(`s`x'4')^2)) if _n==4
	replace `x'_z = abs((``x'3' - ``x'4')/sqrt((`s`x'3')^2+(`s`x'4')^2)) if _n==5
	
	replace `x'_pval = 2*normal(-`x'_z)
	replace `x'_z = round(`x'_z, 0.01)
	replace `x'_pval = round(`x'_pval, 0.01)
	}
	l
		
* CATHOLICS VS. PROTESTANTS:
	/* "Figure 7 shows that the percentage of scholars with 
	zero publications was 13.3\% in Protestant institutions and 49.8\% in 
	Catholic institutions" */
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	keep if (Catholic==1 & Fdate>1527) | (Protestant==1 & Fdate>1527)
	keep ID Father Son Slibh Flibh Catholic Protestant Fdate Fin Sin
	rename Slibh libhold_1
	rename Flibh libhold_0
	reshape long libhold_, i(ID) j(j)
	gen name = Father if j==0
	replace name = Son if j==1
	drop Father Son
	bys libhold_ name Catholic Protestant: keep if _n==1
	count if Catholic==1
	local cath0 = `r(N)'
	count if Catholic==1 & libhold_==0
	local c1 = round(100*`r(N)'/`cath0',0.1)
	count if Protestant==1
	local prot0 = `r(N)'
	count if Protestant==1 & libhold_==0
	local p1 = round(100*`r(N)'/`prot0',0.1)
	di "% catholics with zero pubs: `c1'"
	di "% protestant with zero pubs: `p1'"
	/* "Conditional on having at least one publication, the average scholar had 
	three times more publications in a Protestant institution than in a Catholic 
	institution (320 vs 98 in levels)." */
	gen asinhlibhol = asinh(libhold_)
	summ asinhlibhol if Catholic==1 & libhold_>0
	local avcath = `r(mean)'
	summ asinhlibhol if Protestant==1 & libhold_>0
	local avprot = `r(mean)'
	di "av catholic in levels:"
	di round(sinh(`avcath'),1)	
	di "av protestant in levels:"
	di round(sinh(`avprot'),1)	
	di "ratio:"
	di round(sinh(`avprot'),1)/round(sinh(`avcath'),1)	
	/* "While the observed Protestant-Catholic gap in the son's mean 
	arcsinh-publications is 3.1" */
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	keep if (Catholic==1 & Fdate>1527) | (Protestant==1 & Fdate>1527)
	summ Spubli if Catholic==1
	local avcath = `r(mean)'
	summ Spubli if Protestant==1
	local avprot = `r(mean)'
	di "gap in mean arcsinh-pubs:"
	di round(`avprot'-`avcath',0.1)
	/* "in [the] counterfactual scenario with no nepotism the gap is 2.6" */
	local counterfactualcath = 1.41*`avcath'
	local counterfactualprot = 1.07*`avprot'
	di `counterfactualcath'
	di `counterfactualprot'
	di "counterfactual gap in mean arcsinh-pubs:"
	di round(`counterfactualprot'-`counterfactualcath',0.1)
	/* "... which corresponds to a 16.1\% reduction." */
	local gap = round(`avprot'-`avcath',0.1)
	local countergap = round(`counterfactualprot'-`counterfactualcath',0.1)
	di `gap'
	di `countergap'
	di "% of the cath - prot gap:"
	di round(100*(`countergap'-`gap')/`gap',0.1)

* STATEMENT (N publications in dataset of all scholars after 1525): "we use data from \citeN{RETE34} on 40,800,000 publications of all known scholars active between 1500--1800 to calculate, for each year, the growth rate of publications over the previous 25 years by six fields of study"
	import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
	keep if date>1500
	gen libhold = 0 if publications==0
	replace libhold = sinh(publications) if publications>0
	summ libhold
	collapse (sum) libhold
	l

* % VALIDATION SAMPLE IN MAIN SAMPLE
	import excel "..\database\Families-publis-bis.xlsx", sheet("Sheet1") firstrow clear
	collapse Slibh, by(Son)
	gen valid = 1
	save "dta\sons-in-both-samples.dta", replace
	import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
	collapse Slibh, by(Son)
	merge 1:1 Son using "dta\sons-in-both-samples.dta", gen(_merge0)
	keep if valid==1
	* at the son level
	*tab _merge0
	save "dta\sons-in-both-samples.dta", replace
	* or, at the observation level
	import excel "..\database\Families-publis-bis.xlsx", sheet("Sheet1") firstrow clear
	merge m:1 Son using "dta\sons-in-both-samples.dta", nogen
	tab _merge0
	
* STATEMENT: "fathers and sons in different institutions transmitted their human capital with an elasticity of 0.81, not significantly different than our baseline elasticity"
	clear
	set obs 1
	gen test = "Baseline vs. diff unis" if _n==1
	gen b_z = .
	gen b_pval = .
	* Baseline
	local b1 = 0.63
	local sb1 = 0.04
	* Different unis
	local b2 = 0.81
	local sb2 = 0.15
	* CLOGG ET AL. TESTS
	foreach x in b{
	replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2)) if _n==1
	replace `x'_pval = 2*normal(-`x'_z)
	replace `x'_z = round(`x'_z, 0.01)
	replace `x'_pval = round(`x'_pval, 0.01)
	}
	l
* ==============================================================================



* ==============================================================================
* FIGURE 1: Publications of sons of scholars relative to outsiders overtime
* ------------------------------------------------------------------------------
* Fathers' indicator
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
collapse Flibh, by(Father)
rename Father PKey
gen ifather = 1
save "dta\fathers.dta", replace
* Sons and all data
import excel "..\database\Sons-and-all.xlsx", sheet("Sheet1") firstrow clear
merge m:1 PKey using "dta\fathers.dta", keep(mas mat)
* titles
// library holdings
gen libhold = 0 if publications==0
replace libhold = sinh(publications)-1 if publications>0
gen alibhold = libhold if group=="All" & ifather!=1 	// outsiders
gen slibhold = libhold if group=="Sons"					// sons
// drop top 1%
qui summ publications, d
drop if publications>=`r(p99)'
* sample
keep if worldcat==1 & (covBroad==1 | covComprehensive==1)
count if (group=="All" & ifather!=1) | (group=="Sons")
* collapse and compute moving averages
gen sons = 1 if group=="Sons"
collapse (mean) alibhold (mean) slibhold (count) sons, by(date)
tsset date
keep if date>1250
* innverse hyperbolic
gen asinhalibhold = asinh(alibhold)
gen asinhslibhold = asinh(slibhold)
tssmooth ma ma_aw1 = asinhalibhold, window(25 1 25)
tssmooth ma ma_sw1 = asinhslibhold, window(25 1 25)
tssmooth ma ma_aw2 = asinhalibhold, window(50 1 50)
tssmooth ma ma_sw2 = asinhslibhold, window(50 1 50)
gen ma_aw = ma_aw1 if date>1400
replace ma_aw = ma_aw2 if date<=1400
gen ma_sw = ma_sw1 if date>1400
replace ma_sw = ma_sw2 if date<=1400
* ratio of scholar's sons relative to outsiders
gen ratio = ma_sw/ma_aw
/* Numbers for intro statement: "Between 1088 and 1800, ... the library holdings 
of the average son are 83.4% those of the average outsider.
*/
summ ratio
di round(100*`r(mean)',0.1)
* figure in ratio
twoway 	(line ratio date if date<1800, lcolor(dkgreen) lwidth(medthick)) ///
		, ytitle("arcsinh library holdings (ratio)") xtitle("Date active") ///
		xline(1543, lcolor(bluishgray) lwidth(thick) lpattern(solid)) ///
		xline(1688, lcolor(bluishgray) lwidth(thick) lpattern(solid)) ///
		xline(1632, lcolor(bluishgray) lwidth(thick) lpattern(dash)) ///
		text(1.33 1615.5 "Scientific", color(gray) size(medium)) ///
		text(1.25 1615.5 "Revolution", color(gray) size(medium)) ///
		text(1.25 1760 "Enlightenment", color(gray) size(medium)) ///
		yline(1, lc(red)) ///
		ylabel(0.5(0.1)1.4, angle(horizontal)) xlabel(1250(50)1825) ///
		aspectratio(0.5) graphregion(fc(white) lc(white)) name(B, replace)
graph export "figtabs\Figure1.pdf", as(pdf) name("B") replace
* ==============================================================================


* ==============================================================================
* TABLE 1: Data coverage (in %)
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear

* Coverage and period variables
gen cov1 = 100*CovComprehensive
gen cov2 = 100*CovBroad
*
gen period = 2 if Fdate<1543
replace period = 3 if Fdate>=1543 & Fdate<1632
replace period = 4 if Fdate>=1632 & Fdate<1688
replace period = 5 if Fdate>=1688

* Nobs
qui count
local N1 `r(N)'
forvalues p = 2/5{
qui count if period==`p'
local N`p' `r(N)'
}

* Matrix to store results
mat define tabCOV = (.,.,.,.,`N1'\.,.,.,.,`N2'\.,.,.,.,`N3'\.,.,.,.,`N4'\.,.,.,.,`N5')
mat colnames tabCOV = "Compr" "Broad" "C or B" "Partial" "N"
mat rownames tabCOV = "All" "pre 1543" "SR I" "SR II" "Enlig"

forvalues i=1/5{
forvalues j = 1/2{
	summ cov`j' if period==`i'
	if `i'==1{
		summ cov`j'
	}
	local m`j' = round(`r(mean)',0.1)
	mat tabCOV[`i',`j'] = `m`j''	
}
mat tabCOV[`i',2] = `m2'
mat tabCOV[`i',3] = `m1'+`m2'
mat tabCOV[`i',4] = 100-`m1'-`m2'
}

mat list tabCOV
esttab matrix(tabCOV, fmt(1 1 1 1 0))
esttab matrix(tabCOV, fmt(1 1 1 1 0)) using "figtabs\Table1.tex", mlabel("Table coverage") replace
* ==============================================================================


* ==============================================================================
* FIGURE 3: Number of scholar families and father's publications
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
label var Fpubli "Library holdings (inverse hyperbolic)"
twoway (hist Fdate, freq color(*.7)) ///
	(scatter Fpubli Fdate, yaxis(2) ms(Oh) msize(medlarge) mc(black) mlw(vthin)) ///
	(lpoly Fpubli Fdate if Fpubli>0, yaxis(2) ms(none) mc(none) mlw(none) lcolor(red) lwidth(thick)) ///
	, legend(on order(1 "Families (left axis)" 2 "Publications (right axis)" 3 "Trend publications | >0 (lpoly smooth)") size(large) rows(4) ring(0) position(11) region(lc(black))) ///
	ylabel(#5, axis(1) labsize(large)) ylabel(#4, axis(2) labsize(large)) xlabel(1000(100)1800, labsize(large)) ///
	xtitle("Father's reference date", size(vlarge)) ///
	ytitle("Library holdings" "(inverse hyperbolic)", size(vlarge) axis(2)) ///
	ytitle("Frequency", size(vlarge) axis(1)) ///
	graphregion(color(white)) ysize(3) 
graph export "figtabs\Figure3.pdf", as(pdf) name("Graph") replace
* ==============================================================================


* ==============================================================================
* FIGURE 6: Empirical and simulated distribution of publications
* ------------------------------------------------------------------------------
ssc install cdfplot, replace
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
gen id = _n
rename Fpubli publi1
rename Spubli publi2
keep id publi1 publi2
reshape long publi, i(id) j(gen)
insobs 1

drop if publi>12
cdfplot publi, by(gen) opt1(lp(solid dash)) legend(on order(1 "Fathers" 2 "Sons") ring(0) position(5)) title("A. Data", margin(medium)) name(A, replace) xlabel(0(2)12) xtitle("arcsinh-publications") ytitle("CDF (%)") ylabel(0 "0" 0.2 "20" 0.4 "40" 0.6 "60" 0.8 "80" 1 "100") aspect(0.95)
*
import excel "..\estimation\simulated publi mod2.xlsx", sheet("Sheet1") firstrow clear
gen id = _n
rename FPubli publi1
rename SPubli publi2
keep id publi1 publi2
reshape long publi, i(id) j(gen)
drop if publi>12
cdfplot publi, by(gen) opt1(lp(solid dash)) legend(on order(1 "Fathers" 2 "Sons") ring(0) position(5)) title("C. Model without nepotism", margin(medium)) name(B, replace) xlabel(0(2)12) xtitle("arcsinh-publications") ytitle("CDF (%)") ylabel(0 "0" 0.2 "20" 0.4 "40" 0.6 "60" 0.8 "80" 1 "100") aspect(0.95)
*
import excel "..\estimation\simulated publi mod3.xlsx", sheet("Sheet1") firstrow clear
gen id = _n
rename FPubli publi1
rename SPubli publi2
keep id publi1 publi2
reshape long publi, i(id) j(gen)
drop if publi>12
cdfplot publi, by(gen) opt1(lp(solid dash)) legend(on order(1 "Fathers" 2 "Sons") ring(0) position(5)) title("B. Baseline model", margin(medium)) name(C, replace) xlabel(0(2)12) xtitle("arcsinh-publications") ytitle("CDF (%)") ylabel(0 "0" 0.2 "20" 0.4 "40" 0.6 "60" 0.8 "80" 1 "100") aspect(0.95)
*
graph combine A C B, name(comb, replace) rows(1)
graph export "figtabs\Figure6.pdf", replace
* ==============================================================================



* ==============================================================================
* FIGURE 7: Publications, by institution's religious affiliation
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
keep if (Catholic==1 & Fdate>1527) | (Protestant==1 & Fdate>1527)
keep ID Father Son Slibh Flibh Catholic Protestant Fdate Fin Sin
rename Slibh libhold_1
rename Flibh libhold_0
reshape long libhold_, i(ID) j(j)
gen name = Father if j==0
replace name = Son if j==1
drop Father Son
bys libhold_ name Catholic Protestant: keep if _n==1
gen asinhlibhol = asinh(libhold_)
tab asinhlibhol if Catholic==1
tab asinhlibhol if Protestant==1
summ asinhlibhol if Catholic==1
local Ncat = r(N)
summ asinhlibhol if Protestant==1
local Npro = r(N)
twoway (histogram asinhlibhol if Catholic==1,   freq width(0.5) color(*.5)  lwidth(vvvthin)) ///
       (histogram asinhlibhol if Protestant==1, freq width(0.5) color(none) lcolor(black) lwidth(medium)), ///
	   legend(order(1 "Scholars in Catholic institutions (N=`Ncat')" 2 "Scholars in Protestant institutions (N=`Npro')" ) size(medlarge) rows(2) ring(0) position(1) bmargin(large) region(lstyle(none))) ///
	   xtitle("Library holdings (inverse hyperbolic)", size(medlarge)) ytitle("Frequency", size(medlarge)) ylabel(0(100)500, labs(medium)) xlabel(0(2)14, labs(medium)) ///
	   graphregion(color(white))
graph export "figtabs\Figure7.pdf", replace
* ==============================================================================



* ==============================================================================
* TABLE 5: Heterogeneity (Clogg et al tests, see R files for estimates)
* ------------------------------------------------------------------------------
clear
set obs 6
gen test = "Cath vs prod" if _n==1
replace test = "Cath vs prod, wo theo" if _n==2
replace test = "Same field" if _n==3
replace test = "Growing vs stagnant" if _n==4
replace test = "Appointment date" if _n==5
replace test = "Uni vs acad" if _n==6
gen b_z = .
gen b_pval = .
gen n_z = .
gen n_pval = .

* INFO FROM TABLE 6 (HETEROGENEITY)
* ---------------------------------
* Catholic
local b1 = 0.77
local sb1 = 0.04
local n1 = 29.4
local sn1 = 3.6
* Protestant
local b2 = 0.49
local sb2 = 0.05
local n2 = 6.6
local sn2 = 1.5
* Protestant (excluding theology)
local b3 = 0.47
local sb3 = 0.06
local n3 = 5.0
local sn3 = 2.0
* Same field
local b4 = 0.68
local sb4 = 0.05
local n4 = 21.2
local sn4 = 2.2
* Different field
local b5 = 0.56
local sb5 = 0.07
local n5 = 14.8
local sn5 = 3.2
* Growing field
local b6 = 0.64
local sb6 = 0.04
local n6 = 9.2
local sn6 = 2.3
* Stagnant field
local b7 = 0.78
local sb7 = 0.06
local n7 = 25.3
local sn7 = 4.1
* Son appointed after father's death
local b8 = 0.52
local sb8 = 0.06
local n8 = 15.0
local sn8 = 2.6
* Son appointed before father's death
local b9 = 0.72
local sb9 = 0.05
local n9 = 21.4
local sn9 = 2.0
* Universities
local b10 = 0.68
local sb10 = 0.04
local n10 = 16.5
local sn10 = 2.1
* Academies
local b11 = 0.59
local sb11 = 0.07
local n11 = 10.1
local sn11 = 3.5

* CLOGG TESTS
* ---------------------------------
foreach x in b n{
replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2)) if _n==1
replace `x'_z = abs((``x'1' - ``x'3')/sqrt((`s`x'1')^2+(`s`x'3')^2)) if _n==2
replace `x'_z = abs((``x'4' - ``x'5')/sqrt((`s`x'4')^2+(`s`x'5')^2)) if _n==3
replace `x'_z = abs((``x'6' - ``x'7')/sqrt((`s`x'6')^2+(`s`x'7')^2)) if _n==4
replace `x'_z = abs((``x'8' - ``x'9')/sqrt((`s`x'8')^2+(`s`x'9')^2)) if _n==5
replace `x'_z = abs((``x'10' - ``x'11')/sqrt((`s`x'10')^2+(`s`x'11')^2)) if _n==6
replace `x'_pval = 2*normal(-`x'_z)
replace `x'_z = round(`x'_z, 0.01)
replace `x'_pval = round(`x'_pval, 0.01)
}
l
* ==============================================================================



* ==============================================================================
* TABLE 6: Identified parameters using estimation strategy with outsiders (Column 3)
* ------------------------------------------------------------------------------
clear
set obs 1
gen test = "Difference" if _n==1
foreach x in beta gamma muh sigh sige k nu{ 
gen `x'_z = .
gen `x'_pval = .
}

* INFO FROM TABLE 6
* -----------------
* Baseline estimation
local sigh1 = 4.079
local beta1 = 0.568
local sige1 = 0.309
local muh1 = 3.116
local k1 = 1.268
local nu1 = 8.954
local gamma1 = 14.38
*
local ssigh1 = 0.198
local sbeta1 = 0.042
local ssige1 = 0.125
local smuh1 = 0.358
local sk1 = 0.135
local snu1 = 1.179
local sgamma1 = 1.756

* Estimation with outsiders
local sigh2 = 4.51 
local beta2 = 0.562
local sige2 = 0.248
local muh2 = 3.425
local k2 = 1.354
local nu2 = 8.85
local gamma2 = 14.55
*
local ssigh2 = 0.206
local sbeta2 = 0.041
local ssige2 = 0.094
local smuh2 = 0.348
local sk2 = 0.137
local snu2 = 0.570
local sgamma2 = 1.649


* CLOGG TESTS
* ---------------------------------
foreach x in beta gamma muh sigh sige k nu{ 
replace `x'_z = abs((``x'1' - ``x'2')/sqrt((`s`x'1')^2+(`s`x'2')^2))
replace `x'_pval = 2*normal(-`x'_z)
replace `x'_z = round(`x'_z, 0.001)
replace `x'_pval = round(`x'_pval, 0.001)
}
l
* ==============================================================================


* ==============================================================================
* TABLE 7: Intergenerational elasticities amongst scholars, different methods
* ------------------------------------------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear

* Matrix to store results
mat define tab4 = (.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.\.,.,.)
mat colnames tab4 = "value" "s.e." "N"
mat rownames tab4 = "loglog elasticity, all" "rankrank slope, all" "loglog, im" "rankrank, im" "Multigen" "Multigen (A)" "Model's B"
mat list tab4

* b (loglog elasticity, all)
* --------------------------
gen logSpubli = log(1+Slibh)
gen logFpubli = log(1+Flibh)
reg logSpubli logFpubli
mat tab4[1,1] = _b[logFpubli]
mat tab4[1,2] = _se[logFpubli]
mat tab4[1,3] = `e(N)'

* b (two-generations, intensive)
* ------------------------------

gen logSpubli0 = log(Slibh)
gen logFpubli0 = log(Flibh)
reg logSpubli0 logFpubli0 if Slibh>0 & Flibh>0
mat tab4[3,1] = _b[logFpubli0]
mat tab4[3,2] = _se[logFpubli0]
mat tab4[3,3] = `e(N)'

* rho (rank-rank slope, all)
* --------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear

* create sons' birth cohorts
egen date_cut = cut(Sdate), at(1000(50)1850)
	// make sure every category has at least 100 obs
	replace date_cut = 1750 if date>1799
	replace date_cut = 1500 if date_cut==1450
	replace date_cut = 1450 if date_cut<1450
	tab date_cut
* create ranks
foreach g in S F{
gen `g'rank = .
forvalues t=1450(50)1750{
xtile rank_ = `g'libh if date_cut==`t', nq(100)
replace `g'rank = rank_ if date_cut==`t'
drop rank_
}
}
* regressions
reg Srank Frank
mat tab4[2,1] = _b[Frank]
mat tab4[2,2] = _se[Frank]
mat tab4[2,3] = `e(N)'

* rho (rank-rank slope, intensive)
* --------------------------------
reg Srank Frank if Slibh>0 & Flibh>0
mat tab4[4,1] = _b[Frank]
mat tab4[4,2] = _se[Frank]
mat tab4[4,3] = `e(N)'

* beta (multiple-generation correlations)
* ---------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
replace Flibh = log(1+Flibh)
replace Slibh = log(1+Slibh)
preserve
keep Son Father Flibh Fin
rename Father Grandfather
rename Son Father 
rename Flibh G1libh
rename Fin GFin
duplicates drop
save "dta\grandfathers.dta", replace
restore
qui merge m:1 Father using "dta\grandfathers.dta"
rename Slibh  G3libh
rename Flibh  G2libh

* ratio b_G1-G3 / b_G1-G2
capture program drop myboot
program myboot, rclass
qui reg G3libh G2libh
scalar define b1 = _b[G2libh]
qui reg G3libh G1libh
scalar define b2 = _b[G1libh]
qui return scalar ratio = b2/b1
end
bootstrap ratio =r(ratio), nodots seed(1) reps(5000): myboot
mat tab4[5,1] = e(b)[1,1]
mat tab4[5,2] = e(se)[1,1]
mat tab4[5,3] = e(N)


* beta_A (multiple-generation correlations 2)
* ------------------------------------------
import excel "..\database\Families-publis.xlsx", sheet("Sheet1") firstrow clear
replace Flibh = log(1+Flibh)
replace Slibh = log(1+Slibh)
preserve
keep Son Father Flibh Fin
rename Father Grandfather
rename Son Father 
rename Flibh G1libh
rename Fin GFin
duplicates drop
save "dta\grandfathers.dta", replace
restore
qui merge m:1 Father using "dta\grandfathers.dta"
rename Slibh  G3libh
rename Flibh  G2libh

* ratio b_G1-G3 / average(b_G1-G2,b_G2-G3)
capture program drop myboot
program myboot, rclass
qui reg G3libh G2libh
scalar define b12 = _b[G2libh]
qui reg G2libh G1libh
scalar define b01 = _b[G1libh]
qui reg G3libh G1libh
scalar define b02 = _b[G1libh]
return scalar ratio = b02/((b01+b12)/2)
end
bootstrap ratio =r(ratio), nodots seed(1) reps(5000): myboot
mat tab4[6,1] = e(b)[1,1]
mat tab4[6,2] = e(se)[1,1]
mat tab4[6,3] = e(N)
	

* Model's beta (from R)
* ---------------------
mat tab4[7,1] = 0.632
mat tab4[7,2] = 0.042
mat tab4[7,3] = 1837


esttab matrix(tab4, fmt(2 3 0))
esttab matrix(tab4, fmt(2 3 0)) using "figtabs\Table7.tex", mlabel("Table 7") replace
* ==============================================================================
